-- globals
game = LuaGame(Game)
party = LuaParty(Party)
townState = LuaTownState(TownState)

--[[
	General
]]--

function isAvailable ()
	return true
end

function getSource ()
	return "general"
end

function getName ()
	return "Becoming A Pioneer"
end

function getDescription ()
	return
		"Greetings! In order to go down in history as a famous pioneer you first need to do some things to get started.\n"..
		"Remember that your party is everything, so gather up some men and equip them with tools and items they need. "..
		"But even more importantly - build them a ship to sail.\n"..
		"Check out the Objectives page for list of things you need to accomplish."
end

--[[
	Functions related to objectives
]]--

function getNumberOfObjectives ()
	return 4
end

function getObjectiveText(index)
	if index == 1 then return "Build a Brig"
	elseif index == 2 then return "Increase party size to 2"
	elseif index == 3 then return "Get some basic equipment"
	elseif index == 4 then return "Stock up on food and water"
	else
		return ""
	end
end

function getObjectiveHelpText(index)
	if index == 1 then return "Go to the Harbour and start construction on the first Brig. Then visit the Tavern and advance the season."
	elseif index == 2 then return "Go the Tavern and create a new member for the party. When starting out, a soldier or a hunter would be great addition to the group."
	elseif index == 3 then return "These are the items you should currently purchase from the Supply store: a flask for each of the members, a tent, an axe, a sword or other melee weapon, a bow for hunting and flint for lighting campfires."
	elseif index == 4 then return "Get at least 80 units of fresh water and 100 units of dried meat (or other type of food)."
	else
		return ""
	end
end

function isObjectiveCompleted(index)
	-- Build a Brig
	if index == 1 then
		-- We have a ship
		if party:getVesselCount() > 0 then
			-- And it's not being built
			if LuaShip(party:getVessel(1)):checkStateFlag(Ship.Built) == false then
				return true
			end
		end
	-- Increase party size to 2
	elseif index == 2 then
		if party:getMemberCount() >= 2 then
			return true
		end
	-- Get some basic equipment
	elseif index == 3 then
		local flaskCount = townState:countSupplyTypeTotal(Items.Flask)
		if
			-- One flask for each member, minimum 2 flasks
			(flaskCount >= party:getMemberCount() and flaskCount >= 2) and
			-- At least one of each of the following items
			townState:countSupplyTypeTotal(Items.Tent) > 0 and
			townState:countSupplyTypeTotal(Items.Axe) > 0 and
			townState:countSupplyTypeTotal(Items.Flint) > 0 and
			(townState:countSupplyTypeTotal(Items.Bow) > 0 or townState:countSupplyTypeTotal(Items.Crossbow) > 0) and
			townState:countSupplyCategoryTotal(ItemCategory.MeleeWeapon) > 0 then
			return true
		end
	-- Stock up on food and water
	elseif index == 4 then
		if townState:countSupplyCategoryTotal(ItemCategory.Food) >= 100 and townState:countSupplyTypeTotal(Items.Water) >= 80 then
			return true
		end
	end

	return false
end

--[[
	Functions related to rewards
]]--

function getNumberOfRewards ()
	return 0
end

function shouldAutoCollectRewards ()
	return true
end

function onComplete ()

end
